Package 'EAVA'

Title: Deterministic Verbal Autopsy Coding with Verbal Autopsy Expert Algorithm
Description: Expert Algorithm Verbal Autopsy assigns causes of death to 2016 WHO Verbal Autopsy Questionnaire data. odk2EAVA() converts data to a standard input format for cause of death determination building on the work of Thomas (2021) <https://cran.r-project.org/src/contrib/Archive/CrossVA/>. codEAVA() uses the presence and absence of signs and symptoms reported in the Verbal Autopsy interview to diagnose common causes of death. A deterministic algorithm assigns a single cause of death to each Verbal Autopsy interview record using a hierarchy of all common causes for neonates or children 1 to 59 months of age.
Authors: Emily Wilson [aut, cre], Henry Kalter [aut], Abhirup Datta [aut], Sandipan Pramanik [aut], Robert Black [aut], Gates Foundation [fnd]
Maintainer: Emily Wilson <[email protected]>
License: GPL-3
Version: 1.0.0
Built: 2026-04-27 21:54:32 UTC
Source: https://github.com/emilybrownwilson/eava

Help Index


codEAVA

Description

Assigns cause of death by Verbal Autopsy Expert Algorithm

Usage

codEAVA(df, age_group)

Arguments

df

A data frame with 2016 WHO VA responses in openVA input format

age_group

Age group input, either "neonate" or "child"

Value

A two-column data frame with unique identifier and cause of death

Examples

{
# load embedded example data or data from WHO 2016 Verbal Autopsy Questionnaire
data <- as.data.frame(data_public)
# first run odk2EAVA()
output <- odk2EAVA(data, id_col  = "comsa_id")
# run codEAVA() for neonates and children 1-to-59 months of age
EAVA_neonate <- codEAVA(output, "neonate")
EAVA_child <- codEAVA(output, "child")
head(EAVA_neonate)
head(EAVA_child)
}

Example WHO 2016 Verbal Autopsy Dataset from the Countrywide Mortality Surveillance for Action (COMSA) project in Mozambique

Description

This dataset contains a subset of individual-level responses to the 2016 WHO Verbal Autopsy Instrument as implemented in the Countrywide Mortality Surveillance for Action (COMSA) project in Mozambique.

Usage

data_public

Format

'data_public' is example data frame with 10 rows and 511 columns comprising verbal autopsy questionnaire modules

IDs, geolocation, weighting

comsa_id-adj_wt2007

indetifiers of respondent and interviewer

Id10007-Id10011

age-related variables

All variables with names beginning "age" or "is", such as ageInDays or isNeonatal1

information on the deceased

Id10017-Id10024, Id10051-Id10066

documentation of civil registration

Id10069-Id10073

verification of possible stillbirth

Id10104-ID10116

history of injuries and accidents

Id10077-Id10100

medical history associated with final illness

Id10123-Id10144

general signs and symptoms associated with final illness

Id10147-Id10159

breathing difficulty

Id10161-Id10176

chest pain

Id10178-Id10179

loose stools, vomiting, abdominal pain

Id10181-Id10205

stiff neck, mental confusion, unconciousness, convulsions, skin conditions

Id10207-ID10242

wasting, swelling, lumps, paralysis, discoloration, water consumption

Id10243-Id10270

infant symptom reporting on deaths in children under 1 year

Id10271-Id10283

neonatal symptom reporting on deaths in children under 28 days

Id10284-Id10290, Id10352-Id10357

infant symptom reporting on deaths in children under 1 year

Id10271-Id10283

signs and symptoms associated with pregnancy

Id10294-Id10310

questions about possible maternal symptoms and delivery

Id10312-Id10339, Id10340-Id10347, Id10358-Id10394, Id10376-Id10406

alcohol and tobacco use

Id10411-Id10416

health service utilization

Id10418-Id10446

background and contexg

Id10450-Id10459

Death certificate with cause of death

Id10462-Id10473

Open narrative

Id10476-Id10481

data_public is a subset of the publicly available data from the Countrywide Mortality Surveillance for Action (COMSA) project: https://comsamozambique.org/data-access

the data capture system for this mortality survey was adapted from the 2016 WHO verbal autopsy instrument: https://www.who.int/publications/m/item/verbal-autopsy-standards-the-2016-who-verbal-autopsy-instrument


odk2EAVA

Description

Converts 2016 WHO verbal autopsy (VA) data to an input file for Expert Algorithm Verbal Autopsy cause of death assignment by the codEAVA() function

Usage

odk2EAVA(odk, id_col)

Arguments

odk

A data frame which used open data kit (odk) to obtain 2016 WHO VA questionnaire responses

id_col

A unique identifier for each record within the odk data frame

Value

A data frame that contains variable names and values which have been converted to openVA convention

: odk2EAVA builds on top of odk2openVA_v151() from the CrossVA package https://github.com/cran/CrossVA

References

Thomas J, Choi E, Li Z, Maire N, McCormick T, Byass P, Clark S (2021). CrossVA: Verbal Autopsy Data Transformation for InSilicoVA and InterVA5 Algorithms_. R package version 1.0.0, <https://CRAN.R-project.org/package=CrossVA>.

Examples

{
# load embedded example data or data from WHO 2016 Verbal Autopsy Questionnaire
data <- as.data.frame(data_public)
# run odk2EAVA()
output <- odk2EAVA(data, id_col  = "comsa_id")
# view data converted for use in codEAVA()
head(output)
}